use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
CA
CGI
UA
proxying
Christian
Hansen
chansen
David
Golden
dagolden
Alan
Gardner
gardner
Alessandro
Ghedini
al3xbio
Brad
Gilbert
bgills
Chris
Nehren
apeiron
Weyl
cweyl
Claes
Jakobsson
claes
Clinton
Gormley
clint
Craig
Berry
cberry
Mitchell
davem
Dean
Pearce
pearce
Edward
Zborowski
ed
James
Raspass
jraspass
Jess
Robinson
castaway
Lukas
Eklund
leklund
Martin
Evans
mjegh
Bright
mlbright
Mike
Doherty
doherty
Olaf
Alders
olaf
Petr
Písař
ppisar
Serguei
Trouchelle
stro
Sören
Kornetzki
soeren
Syohei
YOSHIDA
syohex
Tom
Hukins
tom
Tony
Cook
tony
lib
HTTP
Tiny
